@@ -1,6 +1,7 @@
+import cv2 as cv
 import numpy as np
 import qimage2ndarray
-from PySide2 import QtWidgets
+from PySide2 import QtWidgets, QtGui, QtCore
 from PySide2.QtCore import QFile
 from PySide2.QtGui import QIcon, QPixmap
 from PySide2.QtUiTools import QUiLoader
@@ -48,3 +49,28 @@ def remove_widget_from_list_widget(list_widget: QtWidgets.QListWidget, widget: Q
 		if wgt == widget:
 			list_widget.takeItem(list_widget.row(item))
 			break
+
+
+def get_image_from_drop_event(event: QtGui.QDropEvent):
+	mime_data = event.mimeData()
+	image = None
+	if mime_data.hasUrls():
+		urls = mime_data.urls()
+		if len(urls) > 1:
+			return
+		image_path: str = urls[0].url()
+		print(image_path)
+		if not image_path.startswith("file:///"):
+			return
+		# is a file
+		image_path = image_path.replace("file:///", '')
+		image = cv.imread(image_path)
+	elif mime_data.hasFormat('application/x-qabstractitemmodeldatalist'):
+		model = QtGui.QStandardItemModel()
+
+		model.dropMimeData(event.mimeData(), QtCore.Qt.CopyAction, 0, 0, QtCore.QModelIndex())
+		item = model.item(0, 0)
+		image = item.data(QtCore.Qt.UserRole)
+	elif mime_data.hasImage():
+		print("has image")
+	return image
\ No newline at end of file
